package mx.italika.prod.italika.service;

import java.util.List;

import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import mx.italika.prod.italika.model.bean.ResponseBean;
import mx.italika.prod.italika.model.entity.ProductoEntity;
import mx.italika.prod.italika.repository.ProductoRepository;
/**
 * Itzi Enriquez 
 */
@Service
public class ProductoServiceImpl  {


    private ProductoRepository productoRepository;

    
    public ProductoServiceImpl(ProductoRepository productoRepository) {
        this.productoRepository = productoRepository;
    }
    
    
    
    @Transactional
    public List<ProductoEntity> obtenerTodos() {
        return productoRepository.obtenerTodosLosProductos();
    }


    @Transactional
    public void crearProducto(ProductoEntity producto) {
        productoRepository.crearProducto(
            producto.getNombre(),
            producto.getDescripcion(),
            producto.getPrecio(),
            producto.getCantidad()
        );
    }

    @Transactional
    	public ResponseEntity<ResponseBean<Object>> actualizarProducto(Long id, ProductoEntity producto) {
    	    try {
    	        return productoRepository.obtenerProductoPorId(id)
    	            .filter(ProductoEntity::isEstatus) 
    	            .map(productoEntity -> {
    	                productoRepository.actualizarProducto(
    	                    id,
    	                    producto.getNombre(),
    	                    producto.getDescripcion(),
    	                    producto.getPrecio(),
    	                    producto.getCantidad()
    	                );
    	                return ResponseEntity.ok(
    	                    new ResponseBean<>("success", 200, "Actualización de registro exitosa")
    	                );
    	            })
    	            .orElseGet(() -> ResponseEntity.badRequest().body(new ResponseBean<>("error", 901, "Error: El estatus es falso o producto no encontrado")
    	            ));
    	    } catch (Exception e) {
    	        return ResponseEntity.internalServerError().body(
    	            new ResponseBean<>("error", 500, "Error interno del servidor: " + e.getMessage())
    	        );
    	    }
    	}
    @Transactional
    public ResponseEntity<ResponseBean<Object>> eliminarProducto(Long id) {
        try {
            return productoRepository.obtenerProductoPorId(id)
                .filter(ProductoEntity::isEstatus) 
                .map(productoEntity -> {
                    productoRepository.eliminarProducto(id);

                    return ResponseEntity.ok(
                        new ResponseBean<>("success", 200, "El producto fue eliminado exitosamente")
                    );
                })
                .orElseGet(() -> ResponseEntity.badRequest().body(
                    new ResponseBean<>("error", 901, "Error: El estatus es falso o el producto no fue encontrado")
                ));
        } catch (Exception e) {
            return ResponseEntity.internalServerError().body(
                new ResponseBean<>("error", 500, "Error interno del servidor: " + e.getMessage())
            );
        }
    }

}